GUI Calculator: A calculator written in Python
====================================================================

GUI Calculator is a calculator application written in Python using only the standard library.

The tkinter module is used for the interface, the ast module is used for parsing, testing is done by unittest.

Installation
------------

GUI Calculator can be installed using pip:

```bash
python3 -m pip install -U guicalculator
```

How to run
----------

GUI Calculator can be run directly:

```bash
guicalculator
```

or as a module:

```bash
python3 -m guicalculator
```
